@@ -26,7 +26,7 @@ THE SOFTWARE.
 """)
 
 __author__ = "Matthew Marshall <matthew@matthewmarshall.org>"
-__version__ = "0.8"
+__version__ = "0.8.2"
 
 import heapq
 import os.path
@@ -78,7 +78,7 @@ class Scheduler(object):
             # If the IndexError was raised due to something other than an
             # empty heap we don't want to silence it.
             if len(self.heap) != 0:
-                raise e
+                raise
 
 scheduler = Scheduler()
 
@@ -87,17 +87,17 @@ def init_display(size=(640, 480), flags = 0):
     """
     In an ongoing attempt at cleaning up rabbyt, init_display has been
     deprecated and will be removed in a future version.  You can achive the
-    same result by doing this:
+    same result by doing this::
 
-    pygame.init()
-    pygame.display.set_mode(size, pygame.OPENGL | pygame.DOUBLEBUF)
-    rabbyt.set_viewport(size)
-    rabbyt.set_default_attribs()
+        pygame.init()
+        pygame.display.set_mode(size, pygame.OPENGL | pygame.DOUBLEBUF)
+        rabbyt.set_viewport(size)
+        rabbyt.set_default_attribs()
     """
     warn("""
         In an ongoing attempt at cleaning up rabbyt, init_display has been
         deprecated and will be removed in a future version.  You can achive the
-        same result by doing this:
+        same result by doing this::
 
         pygame.init()
         pygame.display.set_mode(size, pygame.OPENGL | pygame.DOUBLEBUF)
@@ -202,4 +202,4 @@ __all__ = __docs_all__ = ('sprites anims primitives collisions '
 'set_load_texture_file_hook ').split()
 # Some people might be using from rabbyt import *.  I might as well keep
 # init_display there for now.
-__all__.append("init_display")
\ No newline at end of file
+__all__.append("init_display")
